# opik-python

To install package in development mode run `pip install -e .` from the repository root directory.

# Linters

Before pushing your changes please run `pre-commit run --all-files` from the python/sdk directory.
It will install and run required linters.
